@@ -221,7 +221,7 @@ class JsonList(list):
     def __radd__(self, other):
         iterable = [item for item in other] + [item for item in self]
         if isinstance(other, JsonList):
-            return self.__class__(iterable, other.list_type)
+            return self.__class__(list_type=other.list_type, iterable=iterable)
         return JsonList(list_type=self.list_type, iterable=iterable)
 
     def __setitem__(self, key, value):
@@ -263,16 +263,16 @@ class JsonList(list):
                 l.append(vars(i)[m])
         return l
 
-    def where(self, m, v, o="=="):
-        nl = type(self)()
-        for i in self:
-            if type(vars(i)[m]) is str or issubclass(type(vars(i)[m]), JsonObject):
-                e = "'%s' %s '%s'" % (str(vars(i)[m]), o, str(v))
-            else:
-                e = "%s %s %s" % (str(vars(i)[m]), o, str(v))
-            if eval(e):
-                nl.append(i)
-        return nl
+    def where(self, m: str, v, o="=="):
+        d = {}
+        if type(v) is str:
+            exec("def criteria(i): return i.%s %s '%s'" % (m, o, v), d)
+        elif isinstance(v, JsonObject):
+            exec("def criteria(i): return str(i.%s) %s '%s'" % (m, o, str(v)), d)
+        else:
+            exec("def criteria(i): return i.%s %s %s" % (m, o, str(v)), d)
+
+        return self.filter(d["criteria"])
 
     def filter(self, l):
         nl = type(self)()
